package domaine;

import outils.Liste;

import java.io.File;
import java.io.FileNotFoundException;
import java.util.LinkedList;

public class ListeDAlarmes extends LinkedList<Alarme> implements Liste<Alarme>, Operable {
    private File fichier;
    private boolean modificationsApportees;
    public ListeDAlarmes() {
        super();
        modificationsApportees = false;
        fichier = null;
    }
    public boolean estVide() { return isEmpty(); }
    public int nombreDElements() { return size(); }
    public void ajoute(Alarme element) { add(element); trie(); }
    public void trie() { sort((Alarme a1, Alarme a2) -> a1.compareTo(a2)); }
    public void retire(int index) { remove(index); }
    public void retire(Alarme element) { remove(element); }
    public Alarme element(int index) { return get(index); }
    public void efface() { clear(); }
    public String nomAffichable() {
        String nom = (modificationsApportees) ? "*" : "";
        if (fichier == null) nom += "Sans nom";
        else nom += fichier.getName();
        return nom;
    }
    public boolean aEteModifiee() {
        return modificationsApportees;
    }
    public void modifiee() {
        modificationsApportees = true;
    }
    public void realise(Operation op) throws Exception {
        op.opereSur(this);
    }
    public ResultatEnregistrementChargement enregistreSous(String nomDeFichier) {
        fichier = new File(nomDeFichier);
        try {
			this.realise(new EnregistrementTexte(nomDeFichier));
        } catch (FileNotFoundException ec) {
        	return ResultatEnregistrementChargement.ERREUR_DE_CREATION;
        } catch (VersionDeFichierNonGeree ev) {
        	return ResultatEnregistrementChargement.ERREUR_DE_VERSION;
    	} catch (Exception e) {
    		return ResultatEnregistrementChargement.ERREUR_D_ECRITURE;
    	}
        modificationsApportees = false;
        return ResultatEnregistrementChargement.REUSSI;
    }
    public ResultatEnregistrementChargement enregistre() { return enregistreSous(fichier.getAbsolutePath()); }
    public ResultatEnregistrementChargement charge(String nomDeFichier) {
        fichier = new File(nomDeFichier);
        try {
        	clear();
         	this.realise(new ChargementTexte(nomDeFichier));
        } catch (FileNotFoundException eo) {
        	return ResultatEnregistrementChargement.FICHIER_INEXISTANT;
        } catch (VersionDeFichierNonGeree ev) {
        	return ResultatEnregistrementChargement.ERREUR_DE_VERSION;
    	} catch (Exception e) {
    		return ResultatEnregistrementChargement.ERREUR_DE_LECTURE;
    	}
        modificationsApportees = false;
        return ResultatEnregistrementChargement.REUSSI;
    }
}
